Models — django-guardian v0.2.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v0.2.2 documentation »
- API Reference »

# Models

Return to API Reference.

## BaseObjectPermission

## UserObjectPermission

class `guardian.managers.` `UserObjectPermissionManager`
  `assign`(perm, user, obj)

    Assigns permission with given `perm` for an instance `obj` and `user`.

  `remove_perm`(perm, user, obj)

    Removes permission `perm` for an instance `obj` and given `user`.

## GroupObjectPermission

class `guardian.managers.` `GroupObjectPermissionManager`
  `assign`(perm, group, obj)

    Assigns permission with given `perm` for an instance `obj` and `group`.

  `remove_perm`(perm, group, obj)

    Removes permission `perm` for an instance `obj` and given `group`.

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v0.2.2 documentation »
- API Reference »